@@ -1,7 +1,7 @@
 import os
 import sys
 
-from minecraft_data.tools import convert
+from minecraft_data.tools import convert, commondata
 
 
 class mod(sys.modules[__name__].__class__):
@@ -11,5 +11,11 @@ class mod(sys.modules[__name__].__class__):
         )
         return type(version, (object,), convert(_dir, version, edition))
 
+    def common(self, edition = 'pc'):
+        _dir = os.path.join(
+            os.path.dirname(__file__), "data/data/"
+        )
+        return type('common', (object,), commondata(_dir, edition))
+
 
 sys.modules[__name__].__class__ = mod
